@@ -30,6 +30,7 @@
 #include "todotreemodel.h"
 #include "todometadatamodel.h"
 #include "testlib/testlib.h"
+#include "testlib/mockmodel.h"
 #include "testlib/modeltest.h"
 #include "testlib/modelbuilderbehavior.h"
 
@@ -829,6 +830,95 @@ private slots:
         QCOMPARE(treeModel, output);
     }
 
+    void shouldReparentOnTodoPromotion()
+    {
+        //GIVEN
+        V inbox(Inbox);
+        C c1(1, 0, "c1");
+        T t1(3, 1, "t1", QString(), "t1");
+        T t2(4, 1, "t2", QString(), "t2");
+
+        // Source structure
+        ModelStructure sourceStructure;
+        sourceStructure << c1
+                        << _+t1
+                        << _+t2;
+
+        //Source model
+        QStandardItemModel source;
+        ModelUtils::create(&source, sourceStructure);
+
+        //create treeModel
+        TodoTreeModel treeModel;
+        ModelTest modelTest(&treeModel);
+
+        treeModel.setSourceModel(&source);
+
+        //WHEN
+        ModelPath itemToPromote = c1 % t1;
+        QModelIndex index = ModelUtils::locateItem(&source, itemToPromote);
+        source.setData(index, Zanshin::ProjectTodo, Zanshin::ItemTypeRole);
+
+        //THEN
+        ModelStructure outputStructure;
+        outputStructure << inbox
+                        << _+t2
+                        << c1
+                        << _+t1;
+
+        QStandardItemModel output;
+        ModelUtils::create(&output, outputStructure);
+
+        QCOMPARE(treeModel, output);
+    }
+
+    void shouldReactToModelReset_data()
+    {
+        QTest::addColumn<ModelStructure>("sourceStructure");
+
+        // Base items
+        C c1(1, 0, "c1");
+        T t1(1, 1, "t1", QString(), "t1", InProgress, ProjectTag);
+        T t2(2, 1, "t2", "t1", "t2");
+
+        // Create the source structure once and for all
+        ModelStructure sourceStructure;
+        sourceStructure << c1
+                        << _+t1
+                        << _+t2;
+
+        QTest::newRow("clear model") << sourceStructure;
+    }
+
+
+    void shouldReactToModelReset()
+    {
+        //GIVEN
+        QFETCH(ModelStructure, sourceStructure);
+
+        //Source model
+        MockModel source;
+        ModelUtils::create(&source, sourceStructure);
+
+        //create treeModel
+        TodoTreeModel treeModel;
+        ModelTest t2(&treeModel);
+
+        treeModel.setSourceModel(&source);
+
+        //WHEN
+        source.clearData();
+
+        //THEN
+        MockModel output;
+        TodoTreeModel* treeModelOutput = new TodoTreeModel();
+
+        treeModelOutput->setSourceModel(&output);
+
+        QAbstractItemModel* abstractModel = treeModelOutput;
+        QCOMPARE(treeModel, *abstractModel);
+        delete treeModelOutput;
+    }
 };
 
 QTEST_KDEMAIN(TodoTreeModelSpec, GUI)
